; Load COM environment
(vl-load-com)

; Open drawing in the background and import all dimension styles
(defun c:AccessExternalDrawing ( / acdbObj cntDimstyles acObject
                                   arTemp arDimStyles cntStep)

  ;; Load the ObjectDBX library
  (if (= acLibImport nil)
    (progn
      (vlax-import-type-library :tlb-filename "C:\\Program Files\\Common Files\\Autodesk Shared\\axdb20enu.tlb"
                                :methods-prefix "acdbm-"
                                :properties-prefix "acdbp-"
                                :constants-prefix "acdbc-"
      )
      (setq acLibImport T)
    )
  )

  ; Create a reference to the ObjectDBX object
  (setq acdbObj (vlax-create-object "ObjectDBX.AxDbDocument.20"))

  ; Open drawing file
  (acdbm-open acdbObj (findfile "External Drawing.dwg"))

  ; Set the counter for dimension styles to zero
  (setq cntDimstyles 0)

  ; Loop through the dimension styles collection
  (vlax-for acObject (vla-get-Dimstyles acdbObj)

    ; Get the current values in the array and then adjust the size
    (setq arTemp arDimStyles)
    (setq arDimStyles (vlax-make-safearray
                          vlax-vbObject (cons 0 cntDimstyles)))

    ; Step through the old array values and
    ; load them into the new array
    (setq cntStep 0)
    (repeat cntDimstyles 
      (vlax-safearray-put-element arDimStyles
            cntStep (vlax-safearray-get-element arTemp cntStep))
      (setq cntStep (1+ cntStep))
    )
  
    ; Add the dimension style to the array
    ; and increment the counter by 1
    (vlax-safearray-put-element arDimStyles cntDimstyles acObject)
    (setq cntDimstyles (1+ cntDimstyles))
  )

  ; Create a reference to AutoCAD
  (setq acadObj (vlax-get-acad-object))

  ; Create a reference to the current drawing
  (setq docObj (vla-get-activedocument acadObj))

  ; Create a reference to the database object of the drawing
  (setq dbObj (vla-get-database docObj))

  ; Create a reference to the 
  (setq dimstylesColl (vla-get-dimstyles dbObj))

  ; Copy the dimension styles from the drawing
  ; open in memory to the current drawing
  (vla-copyobjects acdbObj arDimStyles dimstylesColl)

  ; Release the ObjectDBX object
  (vlax-release-object acdbObj)
 (princ) 
)


; Parses the Notes.xml file
(defun c:ReadXML ( / )
  ; Import the Microsoft XML library
  (if (= xmlLibImport nil)
    (progn
      (vlax-import-type-library :tlb-filename "c:\\windows\\system32\\msxml6.dll"
                                :methods-prefix "xmlm-"
                                :properties-prefix "xmlp-"
                                :constants-prefix "xmlc-"
      )
      (setq xmlLibImport T)
    )
  )

  ; Create and configure the XML Document object
  (setq oXMLDoc (vlax-create-object "MSXML2.DOMDocument"))
  (xmlp-put-async oXMLDoc :vlax-false)
  (xmlp-put-validateOnParse oXMLDoc :vlax-false)

  ; Load the XML file
  (xmlm-load oXMLDoc (findfile "notes.xml"))

  ; Gets the Root node of the XML file
  (setq oNodeCatalog (xmlp-get-documentElement oXMLDoc))
  (setq oChildNodes (xmlp-get-ChildNodes oNodeCatalog))

  ; Step through each Note in the XML file
  (setq cntNote 0)
  (while (< cntNote (xmlp-get-length oChildNodes))
    ; Gets and display the ID of the Note element
    (setq oNote (xmlp-get-Item oChildNodes cntNote))
    (prompt (strcat "\nID: " 
       (xmlp-get-Text (xmlp-get-Item (xmlp-get-Attributes oNote) 0))))

    ; Gets the children of the Note element
    (setq oNoteChildNodes (xmlp-get-ChildNodes oNote))

    ; Step through each Note element
    (setq cntNoteChild 0)
    (while (< cntNoteChild (xmlp-get-length oNoteChildNodes))
      ; Get the node under the Note element
      (setq oNoteChild (xmlp-get-Item oNoteChildNodes cntNoteChild))
      (prompt (strcat "\n" (xmlp-get-BaseName oNoteChild)
		      ": " (xmlp-get-Text oNoteChild)))

      ; Increment the counter
      (setq cntNoteChild (1+ cntNoteChild))
    )
    
    (setq cntNote (1+ cntNote))
  )

  ; Release the XML Document object
  (vlax-release-object oXMLDoc)
)
