; Hard coded path for a LSP file, not ideal in programming
(load "C:\\Program Files\\Autodesk\\AutoCAD 2015\\Tutorial\\VisualLISP\\Lesson1\\gpmain.lsp")

; No path to the LSP file; requires a deeper path setup in AutoCAD 
(load "gpmain.lsp")

; Partial path to the LSP file 
(load (findfile "Tutorial\\VisualLISP\\Lesson1\\gpmain.lsp"))


;|-----------------------------------------------------------------------|;

; Copies the files that a drawing is dependent on to c:\Export_Project
(defun c:FileDependencies ( / acadObj acDoc acFileDependencies 
                              strDestinationDir strFileName
                              strFileExt strFileLocation)
  (setq acadObj (vlax-get-acad-object))
  (setq acDoc (vlax-get-property acadObj 'ActiveDocument))
  (setq acFileDependencies 
        (vlax-get-property acDoc 'FileDependencies))

  (setq strDestinationDir "c:\\export_project")

  (if (= (findfile strDestinationDir) nil)
    (vl-mkdir strDestinationDir)
  )

  (setq strDestinationDir (strcat strDestinationDir "\\"))

  ; Loop through the FileDependency collection
  (vlax-for acFileDependency acFileDependencies

    ; Get the file name
    (setq strFileName 
          (vlax-get-property acFileDependency
                             'FullFileName))

    (setq strFoundPath 
          (vlax-get-property acFileDependency
                             'FoundPath))

    ; Get the file path for the file
    (if (/= (vlax-get-property acFileDependency 'FoundPath) "")
      (setq strFileLocation (strcat strFoundPath strFileName))
      (setq strFileLocation strFileName)
    )

    (setq strFileExt (substr (vl-filename-extension strFileLocation) 2)
          strFileNameOnly (vl-filename-base strFileLocation)
    )
    
    ; Check to see if the file is found at the location provided
    (if (/= (findfile strFileLocation) nil)
      (progn
        ;; Check to see if the directory exists
        (if (= (findfile (strcat strDestinationDir strFileExt)) nil)
          (createDirectoryPaths
              (strcat strDestinationDir strFileExt)
          )
        )

        ; Copy the file to the directory
        (vl-file-copy strFileLocation
                      (strcat strDestinationDir strFileExt "\\" 
                              strFileNameOnly "." strFileExt)
        )
      )
    )
  )
 (princ)
)

; Utility function to build directory paths
; Used with the c:FileDependencies function/command definition.
(defun createDirectoryPaths (folderName / strTemp strTemp2 nSlash)
  (setq strTemp ""
	strTemp2 folderName
	nSlash 0
  )

  ; Check to see if the folderName still has characters left in it
  (while (> (strlen folderName) 0)

    ; Check for a slash
    (setq nSlash (vl-string-search "\\" folderName))
    
    (if (= nSlash 0)
      (setq nSlash (vl-string-search "/" folderName))
      (if (= nSlash nil)(setq nSlash 0))
    )

    ; Get the next directory level to the folderName
    (if (> nSlash 0)
      (progn
        (setq strTemp2 (substr folderName 1 nSlash))
        (setq folderName (substr folderName (+ nSlash 2)))
      )
      (setq strTemp2 folderName
	    folderName "")
    )

    ; Check to see if the last character is a slash or not
    (if (and (/= (substr strTemp2 (strlen strTemp2)) "\\")
             (/= (substr strTemp2 (strlen strTemp2)) "/"))
      (setq strTemp2 (strcat strTemp2 "\\"))
    )
    
    ; Check to see if the directory already exists
    (if (= (findfile (strcat strTemp strTemp2)) nil)
      (vl-mkdir (strcat strTemp strTemp2))
    )

    ; Keep adding to the folder name
    (setq strTemp (strcat strTemp strTemp2))
  )
 (princ)
)
