; Funtion that tests a value to see if it is a string
(defun isstring (valTest / )
  (if (= (type valTest) 'STR)
    T
    nil
  )
)

; Example usage
(isstring 1.25)

(isstring '("Hello"))

(isstring "Hello")


;|-----------------------------------------------------------------------|;

; Example shows how to work with the Description property of a Layer.
(defun c:layerDescription-WithCatch ( / acDoc acLayer acLayers
                                        strLayerName strLayerDesc)
  ; Check to see if the Visual LISP ActiveX functions have been loaded
  (if (/= (type vlax-get-property) 'SUBR)(vl-load-com))
  
  ; Get the active drawing and Layers collection
  (setq acDoc (vlax-get-property
		(vlax-get-acad-object) 'ActiveDocument)
        acLayers (vlax-get-property acDoc 'Layers)
  )

  ; Request the name of the layer to modify
  (while (/= (setq strLayerName
                   (getstring T
		     "\nEnter layer name to add description to: ")) "")

    ; Check to see if the Layer exists in the drawing
    (if (not (vl-catch-all-error-p
               (setq err
                     (vl-catch-all-apply 'vla-item
		       (list acLayers strLayerName)))))
      (progn
        ; Layer exists so ask for a description to add to the Layer
        (setq strLayerDesc
	       (getstring T "\nEnter description for layer: "))

        ; If the user just pressed enter then remove the description
        (if (= strLayerDesc nil)(setq strLayerDesc ""))

        ; Change the Description for the Layer
        (vlax-put-property
          (vla-item acLayers strLayerName) 'Description strLayerDesc)
      )
      (progn
        (prompt (strcat "\nerror: " (vl-catch-all-error-message err)))
        (setq strLayerName "")
      )
    )
  )
  
 (princ)
)


;|-----------------------------------------------------------------------|;


; The following demonstrates the usage of the trace function
(defun OddOrEven (cnt / )
  (if (= (rem cnt 2) 1)
    "ODD"
    "EVEN"
  )
)

(trace OddOrEven)

(defun c:TraceUntrace ( / )
  (setq cnt 10)

  (while (> cnt 0)
    (OddOrEven cnt)

    (setq cnt (1- cnt))
  )
 (princ)
)


;|-----------------------------------------------------------------------|;


; Generates a text file that contains information
; about the AutoLISP environment
(defun c:LISPDump ( / afList nSyms nFuncs nCmds nVars
                          lstSyms lstFuncs lstCmds lstVars
                          item fp)
    (setq afList (atoms-family 1))
    (setq nSyms 0 nFuncs 0 nCmds 0 nVars 0
          lstSyms nil lstFuncs nil lstCmds nil lstVars nil)
    (foreach item aflist
        (progn
           (cond
               ((= (type (eval (read item))) 'SYM)
                    (progn
                        (setq nSyms (1+ nSyms))
                        (if (/= lstSyms nil)
                            (setq lstSyms (append lstSyms (list item)))
                            (setq lstSyms (list item))
                        )
                    )
               )
               ((and (= (type (eval (read item))) 'SUBR) (/= (substr (strcase item) 1 2) "C:"))
                     (progn
                          (setq nFuncs (1+ nFuncs))
                          (if (/= lstFuncs nil)
                              (setq lstFuncs (append lstFuncs (list item)))
                              (setq lstFuncs (list item))
                          )                 
                     )
               )
               ((and (= (type (eval (read item))) 'SUBR) (= (substr (strcase item) 1 2) "C:"))
                     (progn
                          (if (/= (strcase item) (strcase "c:LISPDump"))
                              (progn
                                  (setq nCmds (1+ nCmds))
                                  (if (/= lstCmds nil)
                                      (setq lstCmds (append lstCmds (list item)))
                                      (setq lstCmds (list item))
                                  )
                              )
                          )
                     )
               )
               ((or (= (type (eval (read item))) 'REAL)
                    (= (type (eval (read item))) 'INT)
                    (= (type (eval (read item))) 'LIST)
                    (= (type (eval (read item))) 'PICKSET)
                    (= (type (eval (read item))) 'ENAME)
                    (= (type (eval (read item))) 'VLA-OBJECT)
                    (= (type (eval (read item))) 'FILE)
                    (= (type (eval (read item))) 'VARIANT)
                    (= (type (eval (read item))) 'STR))
                        (progn
                            (setq nVars (1+ nVars))
                            (if (/= lstVars nil)
                                (setq lstVars (append lstVars (list item)))
                                (setq lstVars (list item))
                            )
                        )
               )
           )
        )
    )
    ;; Output details about defined Symbols and Functions
    (prompt (strcat "\nAutoLISP Symbols and Functions count: "
                    "\nSymbols - " (itoa nSyms)
                    "\nFunctions - " (itoa nFuncs)
                    "\nGlobal Variables - " (itoa nVars)
                    "\nCommands - " (itoa nCmds))
    )
    (setq fp (open "c:\\LspDumpFile.log" "w"))
    (write-line "Symbols" fp)
    (setq lstSyms (acad_strlsort lstSyms))
    (foreach item lstSyms
        (write-line item fp)
    )
    (write-line "" fp)
    (write-line "Functions" fp)
    (setq lstFuncs (acad_strlsort lstFuncs))
    (foreach item lstFuncs
        (write-line item fp)
    )
    (write-line "" fp)
    (write-line "Global Variables" fp)
    (setq lstVars (acad_strlsort lstVars))
    (foreach item lstVars
        (write-line item fp)
    )
    (write-line "" fp)
    (write-line "Commands" fp)
    (setq lstCmds (acad_strlsort lstCmds))
    (foreach item lstCmds
        (write-line item fp)
    )
    (close fp)
  (princ)
)