; Load COM environment
(vl-load-com)

; Check to see if our custom command reactors have been loaded into the current drawing
(if (= hyp-rctCmds nil)
  ; Add the command reactors and the custom callbacks
  (setq hyp-rctCmds (vlr-command-reactor nil '((:vlr-commandCancelled . hyp-cmdAbort)
                                               (:vlr-commandEnded . hyp-cmdAbort)
                                               (:vlr-commandFailed . hyp-cmdAbort)
                                               (:vlr-commandWillStart . hyp-cmdStart)
                                              )
                    )
  )
)

; Callback used when the user presses ESCape
; or when the command ends by itself or due to
; a problem
(defun hyp-cmdAbort (param1 param2)
  ; Check to see if our global variable has a value
  ; if it does then set the layer current
  (if (/= hyp-gClayer nil)
    (setvar "clayer" hyp-gClayer)
  )

  ; Clear the global variable
  (setq hyp-gClayer nil)
)

; Callback used when a command is started
(defun hyp-cmdStart (param1 param2)

  ; Store the current layer in a global variable
  (setq hyp-gClayer (getvar "clayer"))

  ; Check to see what command has been started, the
  ; command name is stored in the param2 variable
  (cond
    ; If the QDIM command is active then set the layer
    ; to the Dims layer
    ((= (car param2) "QDIM")(prompt "\nQDIM started"))

    ; If either the HATCH, BHATCH or GRADIENT command
    ; is active then set the current layer to Hatch
    ((or (= (car param2) "HATCH")
	 (= (car param2) "BHATCH")
	 (= (car param2) "GRADIENT")
     )
      (progn
        (if (= (tblsearch "layer" "Hatch") nil)
          (progn
            ; Create a reference to AutoCAD
            (setq acadObj (vlax-get-acad-object))

            ; Create a reference to the current drawing
            (setq docObj (vla-get-activedocument acadObj))

            ; Create the Hatch layer
            (setq layerObj (vla-add (vla-get-layers docObj) "Hatch"))

            ; Set the Hatch layer to red
            (vla-put-color layerObj acRed)
          )
        )
        (setvar "clayer" "Hatch")
      )
    )
  )
)